==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QCameraPermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QCameraPermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCameraPermission")
    QCameraPermission *_ptr = reinterpret_cast<QCameraPermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QCameraPermission()
void __qt_construct_QCameraPermission_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCameraPermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QCameraPermission *__qt_this = new(__qtjambi_ptr) QCameraPermission();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// new QCameraPermission(QCameraPermission)
void __qt_construct_QCameraPermission_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCameraPermission(QCameraPermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QCameraPermission& __qt_other0 = qtjambi_cast<const QCameraPermission& >(__jni_env, other0);
    QCameraPermission *__qt_this = new(__qtjambi_ptr) QCameraPermission(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// destruct QCameraPermission
void __qt_destruct_QCameraPermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCameraPermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QCameraPermission*>(ptr)->~QCameraPermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCameraPermission::QCameraPermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_initialize_1native__Lio_qt_core_QCameraPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCameraPermission::QCameraPermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCameraPermission_0, sizeof(QCameraPermission), typeid(QCameraPermission), false, &deleter_QCameraPermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCameraPermission::QCameraPermission(QCameraPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_initialize_1native__Lio_qt_core_QCameraPermission_2Lio_qt_core_QCameraPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCameraPermission::QCameraPermission(QCameraPermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCameraPermission_1, sizeof(QCameraPermission), typeid(QCameraPermission), false, &deleter_QCameraPermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCameraPermission::operator=(QCameraPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_assign_1native_1cref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::operator=(QCameraPermission)", __qt_this)
        const QCameraPermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QCameraPermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCameraPermission::operator==(QCameraPermission,QCameraPermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_equals_1native_1cref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::operator==(QCameraPermission,QCameraPermission)", __qt_this)
        const QCameraPermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QCameraPermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCameraPermission::swap(QCameraPermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_swap_1native_1ref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::swap(QCameraPermission&)", __qt_this)
        QCameraPermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCameraPermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCameraPermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QCameraPermission>("QCameraPermission", "io/qt/core/QCameraPermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCameraPermission, {
        ConstructorInfo(&__qt_construct_QCameraPermission_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCameraPermission_1, "Lio/qt/core/QCameraPermission;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCameraPermission);
    registerMetaType<QCameraPermission>("QCameraPermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(permissions)

}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QCameraPermission_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(permissions)
#include <QtCore/qpermissions.h>
#endif //QT_CONFIG(permissions)
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(permissions)


void deleter_QCameraPermission(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCameraPermission")
    QCameraPermission *_ptr = reinterpret_cast<QCameraPermission *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(permissions)

// emitting (writeConstructors)
// new QCameraPermission()
void __qt_construct_QCameraPermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCameraPermission()")
#if QT_CONFIG(permissions)
    Q_UNUSED(__java_arguments)
    QCameraPermission *__qt_this = new(__qtjambi_ptr) QCameraPermission();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QCameraPermission::QCameraPermission()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_initialize_1native__Lio_qt_core_QCameraPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCameraPermission::QCameraPermission()")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCameraPermission, sizeof(QCameraPermission), typeid(QCameraPermission), false, &deleter_QCameraPermission, nullptr);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCameraPermission(QCameraPermission)
void __qt_construct_QCameraPermission_cref_QCameraPermission(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCameraPermission(QCameraPermission)")
#if QT_CONFIG(permissions)
    jobject other0 = __java_arguments[0].l;
    const QCameraPermission& __qt_other0 = qtjambi_cast<const QCameraPermission& >(__jni_env, other0);
    QCameraPermission *__qt_this = new(__qtjambi_ptr) QCameraPermission(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
}

// QCameraPermission::QCameraPermission(QCameraPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_initialize_1native__Lio_qt_core_QCameraPermission_2Lio_qt_core_QCameraPermission_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCameraPermission::QCameraPermission(QCameraPermission)")
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCameraPermission_cref_QCameraPermission, sizeof(QCameraPermission), typeid(QCameraPermission), false, &deleter_QCameraPermission, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCameraPermission
void __qt_destruct_QCameraPermission(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCameraPermission")

#if QT_CONFIG(permissions)

    reinterpret_cast<QCameraPermission*>(ptr)->~QCameraPermission();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(permissions)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCameraPermission::operator=(QCameraPermission)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_assign_1native_1cref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::operator=(QCameraPermission)", __qt_this)
        const QCameraPermission& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QCameraPermission>(other0);
        (*__qt_this) = __qt_other0;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCameraPermission::operator==(QCameraPermission,QCameraPermission)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_equals_1native_1cref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::operator==(QCameraPermission,QCameraPermission)", __qt_this)
        const QCameraPermission& __qt_arg__2 = QtJambiAPI::valueReferenceFromNativeId<QCameraPermission>(arg__2);
        __java_return_value = (*__qt_this) == __qt_arg__2;
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(arg__2)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCameraPermission::swap(QCameraPermission&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_swap_1native_1ref_1QCameraPermission__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(permissions)
        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCameraPermission::swap(QCameraPermission&)", __qt_this)
        QCameraPermission& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCameraPermission>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(other0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(permissions)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QCameraPermission_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(permissions)

        const QCameraPermission *__qt_this = QtJambiAPI::objectFromNativeId<QCameraPermission>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(permissions)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCameraPermission(){
    using namespace RegistryAPI;

#if QT_CONFIG(permissions)

    const std::type_info& typeId = registerValueTypeInfo<QCameraPermission>("QCameraPermission", "io/qt/core/QCameraPermission");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCameraPermission, {
        ConstructorInfo(&__qt_construct_QCameraPermission, nullptr)
       ,ConstructorInfo(&__qt_construct_QCameraPermission_cref_QCameraPermission, "Lio/qt/core/QCameraPermission;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCameraPermission);
    registerMetaType<QCameraPermission>("QCameraPermission");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(permissions)

}
